package ch.ethz.inf.vs.nethz.androidtutorial;

import android.content.Intent;
import android.content.SharedPreferences;
import android.hardware.Camera;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCharacteristics;
import android.hardware.camera2.CameraManager;
import android.media.MediaPlayer;
import android.os.Vibrator;
import android.preference.PreferenceManager;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.SeekBar;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.ToggleButton;

import org.w3c.dom.Text;

import java.io.IOException;

public class ActuatorsActivity extends AppCompatActivity implements SharedPreferences.OnSharedPreferenceChangeListener {

    private Vibrator vib = null;
    private int duration = 50;

    private MediaPlayer mp = null;

    private final String KEY_PREF_AUDIO_LOOP = "audio_loop";

    private Camera cam = null;

    private void initPlayer(boolean loop) {
        if (loop) {
            mp = MediaPlayer.create(this, R.raw.loop);
        } else {
            mp = MediaPlayer.create(this, R.raw.sound);
        }
        mp.setLooping(loop);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_actuators);

        vib = (Vibrator) getSystemService(VIBRATOR_SERVICE);
        SeekBar seekBar = (SeekBar) findViewById(R.id.seek_duration);
        seekBar.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            @Override
            public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
                duration = progress;
            }

            @Override
            public void onStartTrackingTouch(SeekBar seekBar) {

            }

            @Override
            public void onStopTrackingTouch(SeekBar seekBar) {
                vib.vibrate(duration*10);
            }
        });

        initPlayer(false);
        PreferenceManager.getDefaultSharedPreferences(this)
                .registerOnSharedPreferenceChangeListener(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        ToggleButton tb = (ToggleButton) findViewById(R.id.btn_torch);
        tb.setChecked(false);
        tb.setText(R.string.btn_torch_off);
    }

    @Override
    public void onPause() {
        super.onPause();

        if (cam!=null) {
            cam.release();
            cam = null;
            Toast.makeText(this, "Camera released", Toast.LENGTH_LONG).show();
        }
    }


    public void onClickVibrate(View v) {
        Vibrator vib = (Vibrator) getSystemService(VIBRATOR_SERVICE);
        long[] pattern = { 0, 100, 100, 200, 100, 100 };
        vib.vibrate(pattern, -1);
    }

    public void onClickSound(View v) {
        if (!mp.isPlaying()) {
            mp.start();
            if (mp.isLooping()) {
                ((Button) v).setText(R.string.btn_running);
            }
        } else {
            mp.pause();
            ((Button) v).setText(R.string.sound);
        }
    }

    public void onClickTorch(View v) {
        ToggleButton tb = (ToggleButton) findViewById(R.id.btn_torch);
        if (tb.isChecked()) {
            cam = Camera.open();
            Camera.Parameters parameters = cam.getParameters();
            parameters.setFlashMode(Camera.Parameters.FLASH_MODE_TORCH);
            cam.setParameters(parameters);
            cam.startPreview();
            tb.setText(R.string.btn_torch_on);
        } else {
            cam.release();
            cam = null;
            tb.setText(R.string.btn_torch_off);
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_actuators, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.menu_settings:
                Intent myIntent = new Intent(this, SettingsActivity.class);
                this.startActivity(myIntent);
                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }

    @Override
    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String key) {
        if (key.equals(KEY_PREF_AUDIO_LOOP)) {
            SharedPreferences sharedPref = PreferenceManager.getDefaultSharedPreferences(this);
            boolean loop = sharedPref.getBoolean(KEY_PREF_AUDIO_LOOP, true);
            initPlayer(loop);
        }
    }
}
